@@ -13,10 +13,10 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Library General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA
  */
 
 #ifdef HAVE_CONFIG_H
@@ -62,13 +62,13 @@
 #include <libxfce4util/libxfce4util.h>
 #include <libxfce4util/libxfce4util-alias.h>
 
-#define XFCE4DIR		".xfce4"
+#define XFCE4DIR ".xfce4"
 
 /* environment variable the user can set to change the path to
  * the users .xfce4 directory. If not set, the xfce_userdir defaults
  * to "$HOME/.xfce4".
  */
-#define	XFCE4HOME_ENVVAR	"XFCE4HOME"
+#define XFCE4HOME_ENVVAR "XFCE4HOME"
 
 G_LOCK_DEFINE_STATIC(_lock);
 
@@ -161,7 +161,7 @@ xfce_version_string (void)
 
 /**
  * xfce_get_homedir:
- * 
+ *
  * Similar to g_get_homedir() in functionality but will never return NULL.
  * While g_get_homedir() may return NULL under certain circumstances, this
  * function is garantied to never ever return NULL, but always return a
@@ -179,7 +179,7 @@ xfce_get_homedir (void)
   if (!xfce_homedir)
     internal_initialize ();
   G_UNLOCK (_lock);
-	
+
   return xfce_homedir;
 }
 
@@ -274,53 +274,9 @@ xfce_get_userfile_r (gchar *buffer, size_t length, const gchar *format, ...)
 
 
 
-/**
- * xfce_strjoin:
- * @separator:
- * @strings:
- * @count:
- *
- * Joins the @count character strings pointed to by @strings using @separator
- * to a single string.
- *
- * Return value: the joined string. The string has to be freed by the caller
- *               using g_free() when no longer needed.
- **/
-gchar*
-xfce_strjoin (const gchar *separator,
-              gchar      **strings,
-              gint         count)
-{
-  gchar *result;
-  gint   length;
-  gint   n;
-
-  g_return_val_if_fail (count < 1, NULL);
-  g_return_val_if_fail (strings != NULL, NULL);
-
-  for (length = 1, n = 0; n < count; n++)
-    length += strlen (strings[n]);
-
-  if (separator != NULL)
-    length += (count - 1) * strlen (separator);
-
-  result = g_new0 (gchar, length);
-
-  for (n = 0; n < count; n++) {
-    g_strlcat (result, strings[n], length);
-
-    if (separator != NULL && n + 1 < count)
-      g_strlcat (result, separator, length);
-  }
-
-  return result;
-}
-
-
-
 /**
  * xfce_gethostname:
- * 
+ *
  * Portable way to query the hostname of the node running the process. This
  * function does not ever return %NULL, but always returns a string containing
  * the current node's hostname.
@@ -333,7 +289,7 @@ xfce_gethostname (void)
 {
 #if defined(HAVE_GETHOSTNAME)
 #ifndef MAXHOSTNAMELEN
-#define MAXHOSTNAMELEN		256
+#define MAXHOSTNAMELEN 256
 #endif
   char hostname[MAXHOSTNAMELEN];
 
@@ -352,149 +308,6 @@ xfce_gethostname (void)
 
 
 
-/**
- * xfce_putenv:
- * @string: Character string in the form "name=value".
- *
- * Portable replacement for the Unix putenv() library function. @string has
- * to have the form "name=value". Calling xfce_putenv() this way is equal to
- * calling xfce_setenv("name", "value", %TRUE).
- *
- * Return value: 0 if the operation was successful; otherwise the global
- *               variable errno is set to indicate the error and a value
- *               of -1 is returned.
- *
- * Since: 4.2
- **/
-gint
-xfce_putenv (const gchar *string)
-{
-#ifdef HAVE_BROKEN_PUTENV
-  gchar* buffer;
-  int result, sverrno;
-  
-  /*
-   * We need to use plattform malloc() here, cause g_malloc() need not
-   * to use malloc(), and we don't know about the evil interna of this
-   * plattforms putenv() implementation.
-   */
-#ifdef HAVE_STRDUP
-  if ((buffer = strdup (string)) != NULL)
-    {
-#else
-  if ((buffer = malloc (strlen (string) + 1)) != NULL)
-    {
-      strcpy(buffer, string);
-#endif
-      if ((result = putenv (buffer)) < 0)
-	{
-	  sverrno = errno;
-	  free (buffer);
-	  errno = sverrno;
-	}
-    }
-  else
-    {
-      errno = ENOMEM;
-      result = -1;
-    }
-
-    return result;
-#else /* !HAVE_BROKEN_PUTENV */
-    return putenv (string);
-#endif /* !HAVE_BROKEN_PUTENV */
-}
-
-
-
-/**
- * xfce_setenv:
- * @name: the name of the environment variable to set, must not contain '='.
- * @value: the value to set the variable to.
- * @overwrite: whether to change the variable if it already exists.
- *
- * If the variable @name does not exists in the list of environment variables,
- * it is inserted with its value being set to @value. If the variable does
- * exist, then its value is only changed to @value if @overwrite is TRUE.
- *
- * On plattforms that provide a working native setenv() library call, this
- * functions is used, on all other plattforms setenv() is emulated using
- * xfce_putenv(). That says, xfce_setenv() is not subject to the limitations
- * that apply to some setenv() implementations and seem also to apply to
- * g_setenv() in Glib 2.4.
- *
- * Return value: 0 if the operation was successful; otherwise the global
- *               variable errno is set to indicate the error and a value
- *               of -1 is returned.
- *
- * Since: 4.2
- **/
-gint
-xfce_setenv (const gchar *name,
-             const gchar *value,
-             gboolean     overwrite)
-{
-  /* Plattforms with broken putenv() are unlikely to have a working setenv() */
-#if !defined(HAVE_SETENV) || defined(HAVE_BROKEN_PUTENV)
-  int result = 0;
-  gchar *buf;
-
-  if (g_getenv (name) == NULL || overwrite)
-    {
-      buf = g_strdup_printf ("%s=%s", name, value);
-      result = xfce_putenv (buf);
-      g_free (buf);
-    }
-
-  return result;
-#else
-  return setenv (name, value, overwrite);
-#endif	/* !HAVE_SETENV */
-}
-
-
-
-/**
- * xfce_unsetenv:
- * @name : the name of the environment variable to unset, must not contain '='.
- *
- * Deletes all instances of the variables @name from the list of environment
- * variables in the current process.
- *
- * Note that on some systems, the memory used for the variable and its value
- * can't be reclaimed. Furthermore, this function can't be guaranteed to
- * operate in a threadsafe way.
- *
- * Since: 4.2
- **/
-void
-xfce_unsetenv (const gchar *name)
-{
-#if defined(HAVE_UNSETENV)
-  unsetenv (name);
-#elif GLIB_CHECK_VERSION(2,4,0)
-  g_unsetenv (name);
-#else
-  /* Adopted the GLib way of doing things, since my putenv (name + "=") does
-   * not work properly on most plattforms :-/
-   */
-  extern char **environ;
-  char **envp1;
-  char **envp2;
-  int    length;
-  
-  length = strlen (name);
-  
-  for (envp1 = envp2 = environ; *envp1 != NULL; ++envp1)
-    if (strncmp (*envp1, name, length) != 0 || (*envp1)[length] != '=')
-      *envp2++ = *envp1;
-
-  *envp2 = NULL;
-#endif
-}
-
-
-
 static inline gboolean
 xfce_is_valid_tilde_prefix (const gchar *p)
 {
@@ -583,7 +396,7 @@ xfce_expand_variables (const gchar *command,
         {
           /* walk to the end of a valid variable name */
           for (start = ++p; *p != '\0' && (g_ascii_isalnum (*p) || *p == '_'); ++p);
-          
+
           if (start < p)
             {
               value = NULL;
